# Annotation of Identified Mutations

Annotation of Identified Mutations to Create Reports for Clinicians to Assist Therapeutic Decisions

## Prerequisites

It requires three main modules: pandas, myvariant and reportlab

```
pip install pandas
pip install myvariant
pip install reportlab
```

## Installing

```
pip install daim
```
